@@ -1,3 +1,6 @@
+"""
+bilibili_api
+"""
 import asyncio
 import platform
 
@@ -8,6 +11,20 @@ from .utils.short import get_real_url
 from .utils.sync import sync
 from .utils.network_httpx import get_session, set_session
 from .utils.parse_link import parse_link, ResourceType
+from . import (
+    app, article, ass, audio, 
+    bangumi, 
+    channel, cheese, comment, 
+    dynamic, 
+    favorite_list, 
+    homepage, 
+    interactive_video, 
+    live, login_func, login, 
+    rank, 
+    search, settings, 
+    user, 
+    video_uploader, video
+)
 
 # UA 头 + Referer
 HEADERS = {"User-Agent": "Mozilla/5.0", "Referer": "https://bilibili.com"}
@@ -15,38 +32,3 @@ HEADERS = {"User-Agent": "Mozilla/5.0", "Referer": "https://bilibili.com"}
 # 如果系统为 Windows，则修改默认策略，以解决代理报错问题
 if "windows" in platform.system().lower():
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
-
-__all__ = [
-    # Constants
-    "HEADERS",
-    # Classes
-    "Credential",
-    "Danmaku", "DmFontSize", "DmMode",
-    # Utils
-    "aid2bvid", "bvid2aid",
-    "parse_link", "ResourceType",
-    "get_real_url",
-    # Requests
-    "get_session", "set_session",
-    # Modules
-    "app",
-    "article",
-    "bangumi",
-    "channel",
-    "cheese",
-    "comment",
-    "dynamic",
-    "favorite_list",
-    "homepage",
-    "interactive_video",
-    "live",
-    "login",    
-    "rank",
-    "search",
-    "settings",
-    "sync",
-    "user",
-    "video_uploader",
-    "video",
-    "vote",
-]
