@@ -6,16 +6,17 @@ bilibili_api.favorite_list
 
 from enum import Enum
 
-from bilibili_api.video import Video
-from bilibili_api import user
-from bilibili_api.utils.network import request
-from bilibili_api.exceptions.ArgsException import ArgsException
-from bilibili_api.utils.Credential import Credential
+from .video import Video
+from . import user
+from .utils.network_httpx import request
+from .exceptions.ArgsException import ArgsException
+from .utils.Credential import Credential
 from .utils.utils import get_api, join
 from typing import List
 
 API = get_api("favorite-list")
 
+
 class FavoriteListContentOrder(Enum):
     """
     收藏夹列表内容排序方式枚举。
@@ -24,12 +25,105 @@ class FavoriteListContentOrder(Enum):
     + VIEW   : 最多播放
     + PUBTIME: 最新投稿
     """
-    MTIME = 'mtime'
-    VIEW = 'view'
-    PUBTIME = 'pubtime'
+
+    MTIME = "mtime"
+    VIEW = "view"
+    PUBTIME = "pubtime"
 
 
-async def get_video_favorite_list(uid: int, video: Video = None, credential: Credential = None):
+class FavoriteListType(Enum):
+    """
+    收藏夹类型枚举
+
+    + VIDEO  : 视频收藏夹
+    + ARTICLE: 专栏收藏夹
+    + CHEESE : 课程收藏夹
+    """
+    VIDEO = "video"
+    ARTICLE = "articles"
+    CHEESE = "pugvfav"
+
+
+class FavoriteList:
+    """
+    收藏夹类
+    """
+    def __init__(
+        self,
+        type_: FavoriteListType = FavoriteListType.VIDEO,
+        media_id: int = None,
+        credential: Credential = Credential(),
+    ) -> None:
+        """
+        Args:
+            type_(FavoriteListType, optional): 收藏家类型. Defaults to FavoriteListType.VIDEO. 
+            media_id(int, optional)          : 收藏家号（仅为视频收藏夹时提供）. Defaults to None. 
+            credential(Credential, optional) : 凭据类. Defaults to Credential(). 
+        """
+        self.type = type_
+        self.media_id = media_id
+        self.credential = credential
+
+    def is_video_favorite_list(self):
+        """
+        收藏夹是否为视频收藏夹
+
+        Returns:
+            bool: 是否为视频收藏夹
+        """
+        return self.type == FavoriteListType.VIDEO
+
+    def get_favorite_list_type(self):
+        """
+        获取收藏夹类型
+
+        Returns:
+            FavoriteListType: 收藏夹类型
+        """
+        return self.type
+
+    async def get_content_video(
+        self,
+        page=1,
+        keyword=None,
+        order: FavoriteListContentOrder = FavoriteListContentOrder.MTIME,
+        tid=0,
+    ):
+        """
+        获取视频收藏夹内容。
+
+        Args:
+            page       (int, optional)                     : 页码. Defaults to 1.
+            keyword    (str, optional)                     : 搜索关键词. Defaults to None.
+            order      (FavoriteListContentOrder, optional): 排序方式. Defaults to FavoriteListContentOrder.MTIME.
+            tid        (int, optional)                     : 分区 ID. Defaults to 0.
+
+        Returns:
+            dict: 调用 API 返回结果。
+        """
+        assert self.type != FavoriteListType.VIDEO, "此函数仅在收藏夹为视频收藏家时可用"
+
+        return await get_video_favorite_list_content(
+            self.media_id, page, keyword, order, tid, self.credential
+        )
+
+    async def get_content(self, page: int = 1):
+        """
+        获取收藏夹内容。
+        """
+        if self.type == FavoriteListType.ARTICLE:
+            return await get_article_favorite_list(page, self.credential)
+        elif self.type == FavoriteListType.CHEESE:
+            return await get_course_favorite_list(page, self.credential)
+        elif self.type == FavoriteListType.VIDEO:
+            return await get_video_favorite_list_content(
+                self.media_id, page, credential=self.credential
+            )
+
+
+async def get_video_favorite_list(
+    uid: int, video: Video = None, credential: Credential = None
+):
     """
     获取视频收藏夹列表。
 
@@ -42,10 +136,7 @@ async def get_video_favorite_list(uid: int, video: Video = None, credential: Cre
         dict: API 调用结果。
     """
     api = API["info"]["list_list"]
-    params = {
-        "up_mid": uid,
-        "type": 2
-    }
+    params = {"up_mid": uid, "type": 2}
 
     if video is not None:
         params["rid"] = video.get_aid()
@@ -59,8 +150,8 @@ async def get_video_favorite_list_content(
     keyword: str = None,
     order: FavoriteListContentOrder = FavoriteListContentOrder.MTIME,
     tid: int = 0,
-    credential: Credential = None
-    ):
+    credential: Credential = None,
+):
     """
     获取视频收藏夹列表内容。
 
@@ -81,11 +172,11 @@ async def get_video_favorite_list_content(
         "pn": page,
         "ps": 20,
         "order": order.value,
-        "tid": tid
+        "tid": tid,
     }
 
     if keyword is not None:
-        params['keyword'] = keyword
+        params["keyword"] = keyword
 
     return await request("GET", api["url"], params=params, credential=credential)
 
@@ -104,10 +195,7 @@ async def get_topic_favorite_list(page: int = 1, credential: Credential = None):
     credential.raise_for_no_sessdata()
 
     api = API["info"]["list_topics"]
-    params = {
-        "pn": page,
-        "ps": 16
-    }
+    params = {"pn": page, "ps": 16}
 
     return await request("GET", api["url"], params=params, credential=credential)
 
@@ -126,10 +214,7 @@ async def get_article_favorite_list(page: int = 1, credential: Credential = None
     credential.raise_for_no_sessdata()
 
     api = API["info"]["list_articles"]
-    params = {
-        "pn": page,
-        "ps": 16
-    }
+    params = {"pn": page, "ps": 16}
 
     return await request("GET", api["url"], params=params, credential=credential)
 
@@ -148,11 +233,7 @@ async def get_album_favorite_list(page: int = 1, credential: Credential = None):
     credential.raise_for_no_sessdata()
 
     api = API["info"]["list_albums"]
-    params = {
-        "page": page,
-        "pagesize": 30,
-        "biz_type": 2
-    }
+    params = {"page": page, "pagesize": 30, "biz_type": 2}
 
     return await request("GET", api["url"], params=params, credential=credential)
 
@@ -172,11 +253,7 @@ async def get_course_favorite_list(page: int = 1, credential: Credential = None)
 
     api = API["info"]["list_courses"]
     self_info = await user.get_self_info(credential)
-    params = {
-        "pn": page,
-        "ps": 10,
-        "mid": self_info["mid"]
-    }
+    params = {"pn": page, "ps": 10, "mid": self_info["mid"]}
 
     return await request("GET", api["url"], params=params, credential=credential)
 
@@ -195,20 +272,17 @@ async def get_note_favorite_list(page: int = 1, credential: Credential = None):
     credential.raise_for_no_sessdata()
 
     api = API["info"]["list_notes"]
-    params = {
-        "pn": page,
-        "ps": 16
-    }
+    params = {"pn": page, "ps": 16}
 
     return await request("GET", api["url"], params=params, credential=credential)
 
 
 async def create_video_favorite_list(
     title: str,
-    introduction: str = '',
+    introduction: str = "",
     private: bool = False,
-    credential: Credential = None
-    ):
+    credential: Credential = None,
+):
     """
     新建视频收藏夹列表。
 
@@ -232,7 +306,7 @@ async def create_video_favorite_list(
         "title": title,
         "intro": introduction,
         "privacy": 1 if private else 0,
-        "cover": ""
+        "cover": "",
     }
 
     return await request("POST", api["url"], data=data, credential=credential)
@@ -241,9 +315,10 @@ async def create_video_favorite_list(
 async def modify_video_favorite_list(
     media_id: int,
     title: str,
-    introduction: str = '',
+    introduction: str = "",
     private: bool = False,
-    credential: Credential = None):
+    credential: Credential = None,
+):
     """
     修改视频收藏夹信息。
 
@@ -270,7 +345,7 @@ async def modify_video_favorite_list(
         "intro": introduction,
         "privacy": 1 if private else 0,
         "cover": "",
-        "media_id": media_id
+        "media_id": media_id,
     }
 
     return await request("POST", api["url"], data=data, credential=credential)
@@ -291,15 +366,15 @@ async def delete_video_favorite_list(media_ids: List[int], credential: Credentia
     credential.raise_for_no_sessdata()
     credential.raise_for_no_bili_jct()
 
-    data = {
-        "media_ids": join(",", media_ids)
-    }
+    data = {"media_ids": join(",", media_ids)}
     api = API["operate"]["delete"]
 
     return await request("POST", api["url"], data=data, credential=credential)
 
 
-async def copy_video_favorite_list_content(media_id_from: int, media_id_to: int, aids: List[int], credential: Credential):
+async def copy_video_favorite_list_content(
+    media_id_from: int, media_id_to: int, aids: List[int], credential: Credential
+):
     """
     复制视频收藏夹内容
 
@@ -322,14 +397,15 @@ async def copy_video_favorite_list_content(media_id_from: int, media_id_to: int,
         "src_media_id": media_id_from,
         "tar_media_id": media_id_to,
         "mid": self_info["mid"],
-        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids))
+        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
     return await request("POST", api["url"], data=data, credential=credential)
 
 
-
-async def move_video_favorite_list_content(media_id_from: int, media_id_to: int, aids: List[int], credential: Credential):
+async def move_video_favorite_list_content(
+    media_id_from: int, media_id_to: int, aids: List[int], credential: Credential
+):
     """
     移动视频收藏夹内容
 
@@ -349,13 +425,15 @@ async def move_video_favorite_list_content(media_id_from: int, media_id_to: int,
     data = {
         "src_media_id": media_id_from,
         "tar_media_id": media_id_to,
-        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids))
+        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
     return await request("POST", api["url"], data=data, credential=credential)
 
 
-async def delete_video_favorite_list_content(media_id: int, aids: List[int], credential: Credential):
+async def delete_video_favorite_list_content(
+    media_id: int, aids: List[int], credential: Credential
+):
     """
     删除视频收藏夹内容
 
@@ -373,7 +451,7 @@ async def delete_video_favorite_list_content(media_id: int, aids: List[int], cre
 
     data = {
         "media_id": media_id,
-        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids))
+        "resources": ",".join(map(lambda x: f"{str(x)}:2", aids)),
     }
 
     return await request("POST", api["url"], data=data, credential=credential)
@@ -394,8 +472,6 @@ async def clean_video_favorite_list_content(media_id: int, credential: Credentia
     credential.raise_for_no_bili_jct()
     api = API["operate"]["content_clean"]
 
-    data = {
-        "media_id": media_id
-    }
+    data = {"media_id": media_id}
 
     return await request("POST", api["url"], data=data, credential=credential)
