@@ -919,3 +919,22 @@ async def check_nickname(nick_name: str = None):
         return False, str(e)
     else:
         return True, ""
+
+
+async def get_self_events(ts: int = 0, credential: Credential = None):
+    """
+    获取自己入站后每一刻的事件
+
+    Args:
+        ts(int, optional)               : 时间戳. Defaults to 0. 
+        credential(Credential, optional): 凭据. Defaults to None. 
+
+    Returns:
+        dict: 调用 API 返回的结果
+    """
+    credential = credential if credential else Credential()
+    api = API["info"]["events"]
+    params = {
+        "ts": ts
+    }
+    return await request("GET", api['url'], params=params, credential=credential)
