@@ -548,7 +548,7 @@ class Video:
 
     async def get_danmakus(
         self, page_index: int = 0, date: datetime.date = None, cid: int = None
-    ):
+    ) -> List[Danmaku]:
         """
         获取弹幕。
 
@@ -637,7 +637,7 @@ class Video:
                     data_type = dm_reader.varint() >> 3
 
                     if data_type == 1:
-                        dm.id = dm_reader.varint()
+                        dm.id_ = dm_reader.varint()
                     elif data_type == 2:
                         dm.dm_time = dm_reader.varint() / 1000
                     elif data_type == 3:
@@ -647,7 +647,7 @@ class Video:
                     elif data_type == 5:
                         dm.color = hex(dm_reader.varint())[2:]
                     elif data_type == 6:
-                        dm.crc32_id = dm_reader.string()
+                        dm.set_crc32_id(dm_reader.string())
                     elif data_type == 7:
                         dm.text = dm_reader.string()
                     elif data_type == 8:
@@ -771,9 +771,9 @@ class Video:
             "bvid": self.get_bvid(),
             "progress": int(danmaku.dm_time * 1000),
             "color": int(danmaku.color, 16),
-            "fontsize": danmaku.font_size.value,
+            "fontsize": danmaku.font_size,
             "pool": pool,
-            "mode": danmaku.mode.value,
+            "mode": danmaku.mode,
             "plat": 1,
         }
         return await request(
@@ -1087,6 +1087,7 @@ class Video:
 
         Args:
             lan        (str)          : 字幕语言代码，参考 http://www.lingoes.cn/zh/translator/langcode.htm
+            
             data       (dict)         : 字幕数据
             submit     (bool)         : 是否提交，不提交为草稿
             sign       (bool)         : 是否署名
@@ -1310,17 +1311,18 @@ class VideoOnlineMonitor(AsyncEvent):
 
         # logger 初始化
         self.logger = logging.getLogger(f"VideoOnlineMonitor-{id_showed}")
-        handler = logging.StreamHandler()
-        handler.setFormatter(
-            logging.Formatter(
-                "[" + str(id_showed) + "][%(asctime)s][%(levelname)s] %(message)s"
+        if not self.logger.handlers:
+            handler = logging.StreamHandler()
+            handler.setFormatter(
+                logging.Formatter(
+                    "[" + str(id_showed) + "][%(asctime)s][%(levelname)s] %(message)s"
+                )
             )
-        )
-        self.logger.addHandler(handler)
-        self.logger.setLevel(logging.INFO if not debug else logging.DEBUG)
+            self.logger.addHandler(handler)
+            self.logger.setLevel(logging.INFO if not debug else logging.DEBUG)
 
-        self.__page_index = page_index
-        self.__tasks = []
+            self.__page_index = page_index
+            self.__tasks = []
 
     async def connect(self):
         """
